@@ -36,7 +36,7 @@ Filter6581::~Filter6581()
 
 void Filter6581::updatedCenterFrequency()
 {
-    const int Vw = f0_dac[fc];
+    const unsigned int Vw = f0_dac[fc];
     hpIntegrator->setVw(Vw);
     bpIntegrator->setVw(Vw);
 }
@@ -45,26 +45,12 @@ void Filter6581::updatedMixing()
 {
     currentGain = gain[vol];
 
-    int ni = 0;
-    int no = 0;
+    unsigned int ni = 0;
+    unsigned int no = 0;
 
-    if (filt1)
-    {
-        ni++;
-    }
-    else
-    {
-        no++;
-    }
+    (filt1 ? ni : no)++;
 
-    if (filt2)
-    {
-        ni++;
-    }
-    else
-    {
-        no++;
-    }
+    (filt2 ? ni : no)++;
 
     if (filt3)
     {
@@ -75,14 +61,7 @@ void Filter6581::updatedMixing()
         no++;
     }
 
-    if (filtE)
-    {
-        ni++;
-    }
-    else
-    {
-        no++;
-    }
+    (filtE ? ni : no)++;
 
     currentSummer = summer[ni];
 
@@ -107,7 +86,7 @@ void Filter6581::updatedMixing()
 void Filter6581::setFilterCurve(double curvePosition)
 {
     delete [] f0_dac;
-    f0_dac = FilterModelConfig::getInstance()->getDAC(FilterModelConfig::getInstance()->getDacZero(curvePosition));
+    f0_dac = FilterModelConfig::getInstance()->getDAC(curvePosition);
     updatedCenterFrequency();
 }
 
