@@ -23,8 +23,6 @@
 
 #include <cmath>
 
-#include "siddefs-fp.h"
-
 #include "Dac.h"
 #include "Integrator.h"
 #include "OpAmp.h"
@@ -83,26 +81,21 @@ FilterModelConfig::FilterModelConfig() :
     WL_snake(1.0 / 115.0),
     dac_zero(6.65),
     dac_scale(2.63),
-    dac_2R_div_R(2.2),
-    dac_term(false),
     vmin(opamp_voltage[0][0]),
     norm(1.0 / ((Vdd - Vth) - vmin))
 {
     // Convert op-amp voltage transfer to 16 bit values.
 
-    double wp = 0.;
-
-    for (int i = 0; i < OPAMP_SIZE; i ++)
+    for (unsigned int i = 0; i < OPAMP_SIZE; i ++)
     {
         if (opamp_voltage[i][0] == opamp_voltage[i][1])
         {
-            wp = opamp_voltage[i][0];
+            opamp_working_point = opamp_voltage[i][0];
+            break;
         }
     }
 
-    opamp_working_point = wp;
-
-    Dac::kinkedDac(dac, DAC_SIZE, dac_2R_div_R, dac_term);
+    Dac::kinkedDac(dac, DAC_BITS, 2.2, false);
 
     const double N16 = norm * ((1 << 16) - 1);
 
@@ -114,7 +107,7 @@ FilterModelConfig::FilterModelConfig() :
     // vc -> vx
     double scaled_voltage[OPAMP_SIZE][2];
 
-    for (int i = 0; i < OPAMP_SIZE; i++)
+    for (unsigned int i = 0; i < OPAMP_SIZE; i++)
     {
         scaled_voltage[i][0] = (N16 * (opamp_voltage[i][0] - opamp_voltage[i][1]) + (1 << 16)) / 2.;
         scaled_voltage[i][1] = N16 * opamp_voltage[i][0];
@@ -138,7 +131,7 @@ FilterModelConfig::FilterModelConfig() :
     // transistors separately would be extremely costly.
     OpAmp opampModel(opamp_voltage, OPAMP_SIZE, Vdd - Vth);
 
-    for (int i = 0; i < 7; i++)
+    for (int i = 0; i < 5; i++)
     {
         const int idiv = 2 + i;        // 2 - 6 input "resistors".
         const int size = idiv << 16;
@@ -211,7 +204,7 @@ FilterModelConfig::FilterModelConfig() :
 
     const double Ut = 26.0e-3;  // Thermal voltage.
     const double k = 1.0;
-    const double Is = 2.*uCox_vcr * Ut * Ut / k * WL_vcr;
+    const double Is = 2. * uCox_vcr * Ut * Ut / k * WL_vcr;
     // Normalized current factor for 1 cycle at 1MHz.
     const double n_Is = N15 * 1.0e-6 / C * Is;
 
@@ -220,7 +213,7 @@ FilterModelConfig::FilterModelConfig() :
 
     for (int Vgx = 1; Vgx < (1 << 16); Vgx++)
     {
-        const double log_term = log(1. + exp((Vgx / N16 - k * Vth) / (2.*Ut)));
+        const double log_term = log(1. + exp((Vgx / N16 - k * Vth) / (2. * Ut)));
         // Scaled by m*2^15
         vcr_n_Ids_term[Vgx] = (unsigned short)(n_Is * log_term * log_term + 0.5);
     }
@@ -228,7 +221,7 @@ FilterModelConfig::FilterModelConfig() :
 
 FilterModelConfig::~FilterModelConfig()
 {
-    for (int i = 0; i < 7; i++)
+    for (int i = 0; i < 5; i++)
     {
         delete [] summer[i];
     }
@@ -248,7 +241,7 @@ double FilterModelConfig::evaluateTransistor(double Vw, double vi, double vx)
 {
     const double Vgst = Vdd - Vth - vx;
     const double Vgdt = Vdd - Vth - vi;
-    const double n_snake = uCox_snake / 2.*WL_snake;
+    const double n_snake = uCox_snake / 2. * WL_snake;
     const double n_I_snake = n_snake * (Vgst * Vgst - Vgdt * Vgdt);
 
     const double Vg = Vdd - Vth - sqrt(pow(Vdd - Vth - Vw, 2.) / 2. + pow(Vgdt, 2.) / 2.);
@@ -257,29 +250,30 @@ double FilterModelConfig::evaluateTransistor(double Vw, double vi, double vx)
 
     const double Ut = 26.0e-3;  // Thermal voltage.
     const double k = 1.0;
-    const double Is = 2.*uCox_vcr * Ut * Ut / k * WL_vcr;
+    const double Is = 2. * uCox_vcr * Ut * Ut / k * WL_vcr;
 
-    const double log_term_f = log(1. + exp((Vgs - k * Vth) / (2.*Ut)));
+    const double log_term_f = log(1. + exp((Vgs - k * Vth) / (2. * Ut)));
     const double n_I_vcr_f = Is * log_term_f * log_term_f;
 
-    const double log_term_r = log(1. + exp((Vgd - k * Vth) / (2.*Ut)));
+    const double log_term_r = log(1. + exp((Vgd - k * Vth) / (2. * Ut)));
     const double n_I_vcr_r = Is * log_term_r * log_term_r;
 
     const double n_I_vcr = n_I_vcr_f - n_I_vcr_r;
     return n_I_snake + n_I_vcr;
 }
 
-unsigned int* FilterModelConfig::getDAC(double dac_zero) const
+unsigned int* FilterModelConfig::getDAC(double adjustment) const
 {
-    const double N16 = norm * ((1L << 16) - 1);
-    const int bits = DAC_SIZE;
-    unsigned int* f0_dac = new unsigned int[1 << bits];
+    const double dac_zero = getDacZero(adjustment);
 
-    for (int i = 0; i < (1 << bits); i++)
+    const double N16 = norm * ((1L << 16) - 1);
+    unsigned int* f0_dac = new unsigned int[1 << DAC_BITS];
+
+    for (int i = 0; i < (1 << DAC_BITS); i++)
     {
         double fcd = 0.;
 
-        for (int j = 0; j < bits; j ++)
+        for (unsigned int j = 0; j < DAC_BITS; j ++)
         {
             if ((i & (1 << j)) != 0)
             {
@@ -287,7 +281,7 @@ unsigned int* FilterModelConfig::getDAC(double dac_zero) const
             }
         }
 
-        f0_dac[i] = (unsigned int)(N16 * (dac_zero + fcd * dac_scale / (1 << bits)) + 0.5);
+        f0_dac[i] = (unsigned int)(N16 * (dac_zero + fcd * dac_scale / (1 << DAC_BITS)) + 0.5);
     }
 
     return f0_dac;
@@ -297,17 +291,16 @@ Integrator* FilterModelConfig::buildIntegrator()
 {
     const double N16 = norm * ((1 << 16) - 1);
     const int Vddt = (int)(N16 * (Vdd - Vth) + 0.5);
-    const int n_snake = (int)((1 << 13) / norm * (uCox_snake / 2.*WL_snake * 1.0e-6 / C) + 0.5);
+    const int n_snake = (int)((1 << 13) / norm * (uCox_snake / 2. * WL_snake * 1.0e-6 / C) + 0.5);
     return new Integrator(vcr_Vg, vcr_n_Ids_term, opamp_rev, Vddt, n_snake);
 }
 
 double FilterModelConfig::estimateFrequency(double dac_zero, int fc)
 {
     /* Calculate input from DAC */
-    const int bits = DAC_SIZE;
     double Vw = 0.;
 
-    for (int j = 0; j < bits; j ++)
+    for (unsigned int j = 0; j < DAC_BITS; j ++)
     {
         if ((fc & (1 << j)) != 0)
         {
@@ -315,7 +308,7 @@ double FilterModelConfig::estimateFrequency(double dac_zero, int fc)
         }
     }
 
-    Vw = dac_zero + dac_scale * Vw / (1 << bits);
+    Vw = dac_zero + dac_scale * Vw / (1 << DAC_BITS);
 
     /* Estimate the behavior for small signals around the op-amp working point. */
     const double vx = opamp_working_point;
