@@ -24,9 +24,6 @@
 
 #include <memory>
 
-#define OPAMP_SIZE 22
-#define DAC_SIZE 11
-
 namespace reSIDfp
 {
 
@@ -36,6 +33,10 @@ class Integrator;
 */
 class FilterModelConfig
 {
+private:
+    static const unsigned int OPAMP_SIZE = 22;
+    static const unsigned int DAC_BITS = 11;
+
 private:
     static std::auto_ptr<FilterModelConfig> instance;
     // This allows access to the private constructor
@@ -51,39 +52,38 @@ private:
 
     // Transistor parameters.
     const double Vdd;
-    const double Vth;			// Threshold voltage
-    const double uCox_vcr;			// 1/2*u*Cox
-    const double WL_vcr;			// W/L for VCR
-    const double uCox_snake;		// 1/2*u*Cox
-    const double WL_snake;			// W/L for "snake"
+    const double Vth;           // Threshold voltage
+    const double uCox_vcr;      // 1/2*u*Cox
+    const double WL_vcr;        // W/L for VCR
+    const double uCox_snake;    // 1/2*u*Cox
+    const double WL_snake;      // W/L for "snake"
 
     // DAC parameters.
     const double dac_zero;
     const double dac_scale;
-    const double dac_2R_div_R;
-    const bool dac_term;
 
     /* Derived stuff */
     const double vmin, norm;
     double opamp_working_point;
     unsigned short* mixer[8];
-    unsigned short* summer[7];
+    unsigned short* summer[5];
     unsigned short* gain[16];
-    double dac[DAC_SIZE];
+    double dac[DAC_BITS];
     unsigned short vcr_Vg[1 << 16];
     unsigned short vcr_n_Ids_term[1 << 16];
     int opamp_rev[1 << 16];
 
+private:
     double evaluateTransistor(double Vw, double vi, double vx);
 
+    double getDacZero(double adjustment) const { return dac_zero - (adjustment - 0.5) * 2.; }
+
     FilterModelConfig();
     ~FilterModelConfig();
 
 public:
     static FilterModelConfig* getInstance();
 
-    double getDacZero(double adjustment) const { return dac_zero - (adjustment - 0.5) * 2.; }
-
     int getVO_T16() const { return (int)(norm * ((1L << 16) - 1) * vmin); }
 
     int getVoiceScaleS14() const { return (int)((norm * ((1L << 14) - 1)) * voice_voltage_range); }
@@ -101,10 +101,10 @@ public:
      * Ownership is transferred to the requester which becomes responsible
      * of freeing the object when done.
      *
-     * @param dac_zero
+     * @param adjustment
      * @return the DAC table
      */
-    unsigned int* getDAC(double dac_zero) const;
+    unsigned int* getDAC(double adjustment) const;
 
     Integrator* buildIntegrator();
 
