@@ -1,5 +1,8 @@
 /*
- * This file is part of reSID, a MOS6581 SID emulator engine.
+ * This file is part of libsidplayfp, a SID player engine.
+ *
+ * Copyright 2011-2013 Leandro Nini <drfiemost@users.sourceforge.net>
+ * Copyright 2007-2010 Antti Lankila
  * Copyright (C) 2004  Dag Lem <resid@nimrod.no>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,10 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- * @author Ken Händel
- *
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef POTENTIOMETER_H
@@ -26,7 +26,7 @@
 namespace reSIDfp
 {
 
-/** @internal
+/**
  * Potentiometer representation.
  *
  * This class will probably never be implemented in any real way.
@@ -34,15 +34,15 @@ namespace reSIDfp
  * @author Ken Händel
  * @author Dag Lem
  */
-class Potentiometer {
-
+class Potentiometer
+{
 public:
-	/**
-	 * Read paddle value. Not modeled.
-	 *
-	 * @return paddle value (always 0xff)
-	 */
-	unsigned char readPOT() const { return (unsigned char) 0xff; }
+    /**
+     * Read paddle value. Not modeled.
+     *
+     * @return paddle value (always 0xff)
+     */
+    unsigned char readPOT() const { return (unsigned char) 0xff; }
 };
 
 } // namespace reSIDfp
