@@ -26,6 +26,7 @@
 
 #include <limits>
 
+#include "array.h"
 #include "Filter6581.h"
 #include "Filter8580.h"
 #include "Potentiometer.h"
@@ -206,7 +207,7 @@ void SID::voiceSync(bool sync)
     if (sync)
     {
         /* Synchronize the 3 waveform generators. */
-        for (int i = 0; i < 3 ; i ++)
+        for (int i = 0; i < 3; i++)
         {
             voice[i]->wave()->synchronize(voice[(i + 1) % 3]->wave(), voice[(i + 2) % 3]->wave());
         }
@@ -215,7 +216,7 @@ void SID::voiceSync(bool sync)
     /* Calculate the time to next voice sync */
     nextVoiceSync = std::numeric_limits<int>::max();
 
-    for (int i = 0; i < 3; i ++)
+    for (int i = 0; i < 3; i++)
     {
         const int accumulator = voice[i]->wave()->readAccumulator();
         const int freq = voice[i]->wave()->readFreq();
@@ -253,7 +254,7 @@ void SID::setChipModel(ChipModel model)
     this->model = model;
 
     /* calculate waveform-related tables, feed them to the generator */
-    array<short>* tables = WaveformCalculator::getInstance()->buildTable(model);
+    matrix_t* tables = WaveformCalculator::getInstance()->buildTable(model);
 
     /* update voice offsets */
     for (int i = 0; i < 3; i++)
@@ -381,7 +382,7 @@ void SID::clockSilent(int cycles)
                 delta_t = 1;
             }
 
-            for (int i = 0; i < delta_t; i ++)
+            for (int i = 0; i < delta_t; i++)
             {
                 /* clock waveform generators (can affect OSC3) */
                 voice[0]->wave()->clock();
