@@ -1,7 +1,7 @@
 /*
  * This file is part of libsidplayfp, a SID player engine.
  *
- * Copyright 2011-2013 Leandro Nini <drfiemost@users.sourceforge.net>
+ * Copyright 2011-2014 Leandro Nini <drfiemost@users.sourceforge.net>
  * Copyright 2007-2010 Antti Lankila
  * Copyright 2004 Dag Lem <resid@nimrod.no>
  *
@@ -29,6 +29,8 @@
 namespace reSIDfp
 {
 
+const int DAC_BITS = 12;
+
 void WaveformGenerator::clock_shift_register()
 {
     // bit0 = (bit22 | test) ^ bit17
@@ -86,21 +88,21 @@ void WaveformGenerator::set_noise_output()
     no_noise_or_noise_output = no_noise | noise_output;
 }
 
-void WaveformGenerator::setWaveformModels(array<short>* models)
+void WaveformGenerator::setWaveformModels(matrix_t* models)
 {
     model_wave = models;
 }
 
 void WaveformGenerator::setChipModel(ChipModel chipModel)
 {
-    double dacBits[12];
-    Dac::kinkedDac(dacBits, 12, chipModel == MOS6581 ? 2.20 : 2.00, chipModel == MOS8580);
+    double dacBits[DAC_BITS];
+    Dac::kinkedDac(dacBits, DAC_BITS, chipModel == MOS6581 ? 2.20 : 2.00, chipModel == MOS8580);
 
-    for (int i = 0; i < 4096; i++)
+    for (int i = 0; i < (1 << DAC_BITS); i++)
     {
         double dacValue = 0.;
 
-        for (int j = 0; j < 12; j ++)
+        for (int j = 0; j < DAC_BITS; j ++)
         {
             if ((i & (1 << j)) != 0)
             {
@@ -111,9 +113,9 @@ void WaveformGenerator::setChipModel(ChipModel chipModel)
         dac[i] = (short)(dacValue + 0.5);
     }
 
-    const int offset = dac[chipModel == MOS6581 ? 0x380 : 0x800];
+    const short offset = dac[chipModel == MOS6581 ? 0x380 : 0x800];
 
-    for (int i = 0; i < 4096; i ++)
+    for (int i = 0; i < (1 << DAC_BITS); i ++)
     {
         dac[i] -= offset;
     }
@@ -182,10 +184,11 @@ void WaveformGenerator::writeCONTROL_REG(unsigned char control)
 
         // FIXME
         // This value has been adjusted aleatorily from the original reSID value (0x4000)
-        // to fix MUSICIANS/H/Hatlelid_Kris/Grand_Prix_Circuit.sid#2
-        // see VICE Bug 3515933
-        // http://sourceforge.net/tracker/?func=detail&aid=3515933&group_id=223021&atid=1057617
-        floating_output_ttl = 0x28000;
+        // to fix /MUSICIANS/H/Hatlelid_Kris/Grand_Prix_Circuit.sid#2
+        // and /MUSICIANS/P/PVCF/Thomkat_with_Strange_End.sid
+        // see VICE Bug #290
+        // http://sourceforge.net/p/vice-emu/bugs/290/
+        floating_output_ttl = 0xF4240;
     }
 }
 
