@@ -22,11 +22,13 @@
 
 #include "mos6510.h"
 
-#include <string.h>
+#include "sidplayfp/event.h"
+#include "sidplayfp/sidendian.h"
 
 #include "opcodes.h"
 
 #ifdef DEBUG
+#  include <cstdio>
 #  include "mos6510debug.h"
 #endif
 
@@ -359,6 +361,10 @@ void MOS6510::FetchDataByte()
     {
         Register_ProgramCounter++;
     }
+
+#ifdef DEBUG
+    instrOperand = Cycle_Data;
+#endif
 }
 
 /**
@@ -378,6 +384,10 @@ void MOS6510::FetchLowAddr()
 {
     Cycle_EffectiveAddress = cpuRead(Register_ProgramCounter);
     Register_ProgramCounter++;
+
+#ifdef DEBUG
+    instrOperand = Cycle_EffectiveAddress;
+#endif
 }
 
 /**
@@ -424,7 +434,7 @@ void MOS6510::FetchHighAddr()
     Register_ProgramCounter++;
 
 #ifdef DEBUG
-    instrOperand = Cycle_EffectiveAddress;
+    endian_16hi8(instrOperand, endian_16hi8(Cycle_EffectiveAddress));
 #endif
 }
 
@@ -493,7 +503,7 @@ void MOS6510::FetchLowPointer()
     Register_ProgramCounter++;
 
 #ifdef DEBUG
-    endian_16lo8(instrOperand, endian_16lo8 (Cycle_Pointer));
+    instrOperand = Cycle_Pointer;
 #endif
 }
 
@@ -524,7 +534,7 @@ void MOS6510::FetchHighPointer()
     Register_ProgramCounter++;
 
 #ifdef DEBUG
-    endian_16hi8(instrOperand, endian_16hi8 (Cycle_Pointer));
+    endian_16hi8(instrOperand, endian_16hi8(Cycle_Pointer));
 #endif
 }
 
@@ -1522,7 +1532,7 @@ MOS6510::MOS6510 (EventContext *context) :
     for (int i = 0; i < 0x100; i++)
     {
 #if DEBUG > 1
-        printf ("Building Command %d[%02x]..", i, i);
+        printf("Building Command %d[%02x]... ", i, i);
 #endif
 
         /*
@@ -2151,10 +2161,6 @@ MOS6510::MOS6510 (EventContext *context) :
         /* check for IRQ triggers or fetch next opcode... */
         instrTable[buildCycle].func = &MOS6510::interruptsAndNextOpcode;
 
-#if DEBUG > 1
-        printf(".");
-#endif
-
 #if DEBUG > 1
         printf("Done [%d Cycles]\n", buildCycle - (i << 3));
 #endif
