@@ -23,24 +23,30 @@
 #ifndef C64_H
 #define C64_H
 
-#include "Banks/Bank.h"
+#include <stdint.h>
+#include <cstdio>
+
 #include "Banks/IOBank.h"
 #include "Banks/ColorRAMBank.h"
 #include "Banks/DisconnectedBusBank.h"
 #include "Banks/SidBank.h"
 #include "Banks/ExtraSidBank.h"
 
+#include "sidplayfp/EventScheduler.h"
+
 #include "sidplayfp/c64/c64env.h"
 #include "sidplayfp/c64/c64cpu.h"
 #include "sidplayfp/c64/c64cia.h"
 #include "sidplayfp/c64/c64vic.h"
 #include "sidplayfp/c64/mmu.h"
 
-
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
 
+class c64sid;
+class sidmemory;
+
 
 #ifdef PC64_TESTSUITE
 class testEnv
@@ -204,7 +210,7 @@ public:
     const EventScheduler &getEventScheduler() const { return m_scheduler; }
     //@}
 
-    void debug(bool enable, FILE *out) { cpu.debug (enable, out); }
+    void debug(bool enable, FILE *out) { cpu.debug(enable, out); }
 
     void reset();
     void resetCpu() { cpu.reset(); }
@@ -230,17 +236,9 @@ public:
     * Set the requested SID
     *
     * @param i sid number to set
-    * @param s the sid emu to set
+    * @param s the sid emu to set, or 0 to remove
     */
-    void setSid(unsigned int i, sidemu *s);
-
-    /**
-    * Return the requested SID
-    *
-    * @param i sid number to get
-    * @return the SID emu
-    */
-    sidemu *getSid(unsigned int i) const;
+    void setSid(unsigned int i, c64sid *s);
 
     /**
     * Set the base address of a stereo SID chip.<br/>
