@@ -22,9 +22,9 @@
 
 #include "player.h"
 
-#include "SidConfig.h"
+#include "sidemu.h"
+#include "SidTune.h"
 #include "sidbuilder.h"
-#include "c64/c64.h"
 
 SIDPLAYFP_NAMESPACE_START
 
@@ -84,7 +84,9 @@ bool Player::config(const SidConfig &cfg)
             m_errorString = e.message();
             m_cfg.sidEmulation = 0;
             if (&m_cfg != &cfg)
-                config (m_cfg);
+            {
+                config(m_cfg);
+            }
             return false;
         }
     }
@@ -101,7 +103,6 @@ bool Player::config(const SidConfig &cfg)
         m_info.m_channels = 1;
     }
 
-    m_mixer.setSids(m_c64.getSid(0), m_c64.getSid(1));
     m_mixer.setStereo(cfg.playback == SidConfig::STEREO);
     m_mixer.setVolume(cfg.leftVolume, cfg.rightVolume);
 
@@ -214,24 +215,26 @@ SidConfig::sid_model_t Player::getModel(SidTuneInfo::model_t sidModel, SidConfig
 
 void Player::sidRelease()
 {
-    for (unsigned int i = 0; i < c64::MAX_SIDS; i++)
+    unsigned int i=0;
+    while (sidemu *s = m_mixer.getSid(i))
     {
-        if (sidemu *s = m_c64.getSid(i))
+        if (sidbuilder *b = s->builder())
         {
-            if (sidbuilder *b = s->builder())
-            {
-                b->unlock (s);
-            }
-            m_c64.setSid(i, 0);
+            b->unlock(s);
         }
+        m_c64.setSid(i, 0);
+        i++;
     }
+
+    m_mixer.clearSids();
 }
 
 void Player::sidCreate(sidbuilder *builder, SidConfig::sid_model_t defaultModel,
                         bool forced, unsigned int channels)
 {
     if (builder)
-    {   // Detect the Correct SID model
+    {
+        // Detect the Correct SID model
         // Determine model when unknown
         SidConfig::sid_model_t userModels[c64::MAX_SIDS];
 
@@ -247,8 +250,12 @@ void Player::sidCreate(sidbuilder *builder, SidConfig::sid_model_t defaultModel,
             sidemu *s = builder->lock(m_c64.getEventScheduler(), userModels[i]);
             // Get at least one SID emulation
             if ((i == 0) && !builder->getStatus())
+            {
                 throw new configError(builder->error());
+            }
+
             m_c64.setSid(i, s);
+            m_mixer.addSid(s);
         }
     }
 }
@@ -256,14 +263,13 @@ void Player::sidCreate(sidbuilder *builder, SidConfig::sid_model_t defaultModel,
 void Player::sidParams(double cpuFreq, int frequency,
                         SidConfig::sampling_method_t sampling, bool fastSampling)
 {
-    for (unsigned int i = 0; i < c64::MAX_SIDS; i++)
-    {
-        if (sidemu *s = m_c64.getSid(i))
-        {
-            s->sampling((float)cpuFreq, frequency, sampling, fastSampling);
-        }
-    }
+    unsigned int i = 0;
 
+    while (sidemu *s = m_mixer.getSid(i))
+    {
+        s->sampling((float)cpuFreq, frequency, sampling, fastSampling);
+        i++;
+    }
 }
 
 SIDPLAYFP_NAMESPACE_STOP
