@@ -24,12 +24,16 @@
 #ifndef PLAYER_H
 #define PLAYER_H
 
+#include <stdint.h>
+#include <cstdio>
+
+#include "siddefs.h" 
 #include "SidConfig.h"
-#include "SidTune.h"
 #include "SidTuneInfo.h"
 #include "SidInfoImpl.h"
 #include "sidrandom.h"
 #include "mixer.h"
+#include "event.h"
 #include "c64/c64.h"
 
 #ifdef HAVE_CONFIG_H
@@ -37,9 +41,15 @@
 #endif
 
 #ifdef PC64_TESTSUITE
-#  include <string.h>
+#  include <string>
+#  include "SidTune.h"
+#else
+class SidTune;
 #endif
 
+class SidInfo;
+class sidbuilder;
+
 
 SIDPLAYFP_NAMESPACE_START
 
@@ -90,11 +100,11 @@ private:
 #ifdef PC64_TESTSUITE
     void load(const char *file)
     {
-        char name[0x100] = PC64_TESTSUITE;
-        strcat (name, file);
-        strcat (name, ".prg");
+        std::string name(PC64_TESTSUITE);
+        name.append(file);
+        name.append(".prg");
 
-        m_tune->load (name);
+        m_tune->load(name.c_str());
         m_tune->selectSong(0);
         initialise();
     }
