@@ -36,13 +36,16 @@ class EventContext;
 */ 
 class sidbuilder
 {
+protected:
+    typedef std::set<sidemu*> emuset_t;
+ 
 private:
     const char * const m_name;
 
 protected:
     std::string m_errorBuffer;
 
-    std::set<sidemu *> sidobjs;
+    emuset_t sidobjs;
 
     bool m_status;
 
