@@ -21,18 +21,19 @@
 #ifndef PSID_H
 #define PSID_H
 
+#include <stdint.h>
+
 #include "SidTuneBase.h"
 
+#include "sidplayfp/SidTune.h"
+
 class PSID : public SidTuneBase
 {
 private:
     char m_md5[SidTune::MD5_LENGTH+1];
 
 private:
-    bool resolveAddrs(const uint_least8_t *c64data);
-    bool checkRelocInfo();
-
-    void tryLoad(Buffer_sidtt<const uint_least8_t>& dataBuf);
+    void tryLoad(buffer_t& dataBuf);
 
 protected:
     PSID() {}
@@ -40,7 +41,7 @@ protected:
 public:
     virtual ~PSID() {}
 
-    static SidTuneBase* load(Buffer_sidtt<const uint_least8_t>& dataBuf);
+    static SidTuneBase* load(buffer_t& dataBuf);
 
     virtual const char *createMD5(char *md5);
 
