@@ -25,16 +25,17 @@
 
 #include <stdint.h>
 #include <memory>
+#include <vector>
+#include <string>
 
-#include "sidplayfp/Buffer.h"
-#include "sidplayfp/SmartPtr.h"
+#include "SidTuneCfg.h"
+#include "SmartPtr.h"
+#include "SidTuneInfoImpl.h"
 #include "sidplayfp/SidTuneInfo.h"
-#include "sidplayfp/SidTune.h"
 #include "sidplayfp/siddefs.h"
 
-template class Buffer_sidtt<const uint_least8_t>;
-
-class SidTuneInfoImpl;
+class sidmemory;
+template <class T> class SmartPtr_sidtt;
 
 /**
 * loadError
@@ -53,6 +54,9 @@ public:
 */
 class SidTuneBase
 {
+protected:
+    typedef std::vector<uint_least8_t> buffer_t;
+
 protected:
     /// Also PSID file format limit.
     static const unsigned int MAX_SONGS = 256;
@@ -124,7 +128,7 @@ protected:  // -------------------------------------------------------------
     /// For files with header: offset to real data
     uint_least32_t fileOffset;
 
-    Buffer_sidtt<const uint_least8_t> cache;
+    buffer_t cache;
 
 protected:
     SidTuneBase();
@@ -133,7 +137,7 @@ protected:
     * Does not affect status of object, and therefore can be used
     * to load files. Error string is put into info.statusString, though.
     */
-    static void loadFile(const char* fileName, Buffer_sidtt<const uint_least8_t>& bufferRef);
+    static void loadFile(const char* fileName,buffer_t& bufferRef);
 
     /// Convert 32-bit PSID-style speed word to internal tables.
     void convertOldStyleSpeedToTables(uint_least32_t speed,
@@ -165,7 +169,7 @@ protected:
     * separator is the forward slash.
     */
     virtual void acceptSidTune(const char* dataFileName, const char* infoFileName,
-                        Buffer_sidtt<const uint_least8_t>& buf, bool isSlashedFileName);
+                        buffer_t& buf, bool isSlashedFileName);
 
     class PetsciiToAscii
     {
