@@ -24,25 +24,25 @@
 
 #include <memory>
 
-#include "SidTuneCfg.h"
 #include "SidTuneTools.h"
-#include "SidTuneInfoImpl.h"
+#include "sidplayfp/SidTuneInfo.h"
+#include "sidplayfp/stringutils.h"
 
 const char TXT_FORMAT_PRG[] = "Tape image file (PRG)";
 
 const char ERR_TRUNCATED[]  = "ERROR: File is most likely truncated";
 
 
-SidTuneBase* prg::load(const char *fileName, Buffer_sidtt<const uint_least8_t>& dataBuf)
+SidTuneBase* prg::load(const char *fileName, buffer_t& dataBuf)
 {
     const char *ext = SidTuneTools::fileExtOfPath(fileName);
-    if ( (MYSTRICMP(ext,".prg")!=0) &&
-         (MYSTRICMP(ext,".c64")!=0) )
+    if ( (!stringutils::equal(ext, ".prg")) &&
+         (!stringutils::equal(ext, ".c64")) )
     {
         return 0;
     }
 
-    if (dataBuf.len() < 2)
+    if (dataBuf.size() < 2)
     {
         throw loadError(ERR_TRUNCATED);
     }
