@@ -32,8 +32,7 @@ private:
     void load();
 
 public:
-    static SidTuneBase* load(const char *fileName,
-                             Buffer_sidtt<const uint_least8_t>& dataBuf);
+    static SidTuneBase* load(const char *fileName, buffer_t& dataBuf);
 
     virtual ~prg() {}
 
